import logging
from stPackage_py import unreleased         #con unreleased inicializada en init

"""
MESSAGE INTO LOGGING
1)INFO
2)DEBUG
3)WARNING
4)ERROR
5)CRITICAL

logging.basicConfig(level=logging.DEBUG)
    muestra mensajes de 20 a superiores
"""

logging.basicConfig(level = logging.INFO)

"""     Sin usar DOCSTRINGS
if __name__ == '__main__':
    logging.debug('>>>  Ejecución del paquete iniciada')
    
    workshops = unreleased()
    print(workshops)

    logging.debug('>>> Finalizada la ejecución del paquete')
"""

"""Usando DOSCTRINGS
if __name__ == '__main__':
    logging.debug('>>>  Ejecución del paquete iniciada')
    
    workshops = unreleased()

    logging.debug(unreleased())
    #logging.debug(unreleased.__doc__)  En vez de ver los workshops
    #logging.debug(help(unreleased))    Es otra forma de hacerlo

    logging.debug('>>> Finalizada la ejecución del paquete')
"""

#usando entry_points

def main():
    logging.info(unreleased())


if __name__ == '__main__':
    logging.debug('>>>  Ejecución del paquete iniciada')

    main()

    logging.debug('>>> Finalizada la ejecución del paquete')


import requests

#Primer ENTPOINT
#definimos una función que va a realizar la peticion y retorna un JSON
def unreleased():
    """Retorna los próximos talleres en CódigoFacilito
    >>> type(unreleased()) == type(dict())
    True
    """                 #obtenemos el tipo de la funcion y si es igual al tipo diccionario regresa True

    response = requests.get('https://codigofacilito.com/api/v2/workshops/unreleased')

    if response.status_code == 200:     #si fue correcta
        payload = response.json()      #convertimos lo que retorma en un diccionario
        return payload['data']         #en data existe el listado de workshops